@@ -5,16 +5,16 @@ use fuels_signers::provider::Provider;
 use fuels_signers::LocalWallet;
 use std::net::SocketAddr;
 
+/// Launches a provider and provides a test wallet
 #[cfg(feature = "fuels-signers")]
-pub async fn setup_test_provider_and_wallet() -> (Provider, LocalWallet) {
+pub async fn launch_provider_and_get_wallet() -> LocalWallet {
     //  We build only 1 coin with amount DEFAULT_INITIAL_BALANCE, empirically determined to be
     //  sufficient right now
     let (pk, coins) = setup_address_and_coins(1, DEFAULT_INITIAL_BALANCE);
     // Setup a provider and node with the given coins
     let (provider, _) = setup_test_provider(coins).await;
 
-    let wallet = LocalWallet::new_from_private_key(pk, provider.clone());
-    (provider, wallet)
+    LocalWallet::new_from_private_key(pk, provider)
 }
 
 // Setup a test provider with the given coins. We return the SocketAddr so the launched node
